@@ -1,4 +1,4 @@
-from typing import Union, List
+from typing import Union, List, Optional
 from nltk.stem import PorterStemmer
 import numpy as np
 import pandas as pd
@@ -91,17 +91,17 @@ class sentence_tranformer_checker():
     def __init__(
         self, 
         targets: Union[List[str], pd.DataFrame], 
-        target_group: Union[List[str], pd.DataFrame]=None,
-        target_col: str=None, 
-        device: str = None,
-        model: SentenceTransformer=None, 
-        lang: str='en', 
-        only_include: List[str]=None,
-        encode_batch = 32,
-        encode_target = True,
-        remove_punct: bool=True, 
-        remove_stop_words: bool=True, 
-        stemm: bool=False
+        target_group: Optional[Union[List[str], pd.DataFrame]]=None,
+        target_col: Optional[str]=None, 
+        device: Optional[str] = None,
+        model: Optional[SentenceTransformer]=None, 
+        lang: Optional[str]='en', 
+        only_include: Optional[List[str]]=None,
+        encode_batch: Optional[int] = 32,
+        encode_target: Optional[bool] = True,
+        remove_punct: Optional[bool]=True, 
+        remove_stop_words: Optional[bool]=True, 
+        stemm: Optional[bool]=False
     ):    
         """
         parameters:
@@ -200,11 +200,11 @@ class sentence_tranformer_checker():
     def match(
         self, 
         source: Union[List[str], pd.DataFrame], 
-        source_col: str=None, 
-        topn: int=1, 
-        return_match_idx: bool=False, 
-        threshold: float=0.5, 
-        batch_size: int=128
+        source_col: Optional[str]=None, 
+        topn: Optional[int]=1, 
+        return_match_idx: Optional[bool]=False, 
+        threshold: Optional[float]=0.5, 
+        batch_size: Optional[int]=128
     ) -> pd.DataFrame:
         '''
         Main match function. return only the top candidate for every source string.
